#if !SQLITE_QSYSTEM

#include "../../src/app/qgsspatialitesourceselect.cpp"

#endif
